var plplotcmodulePYTHON__wrap_8c =
[
    [ "swig_type_info", "structswig__type__info.html", "structswig__type__info" ],
    [ "swig_cast_info", "structswig__cast__info.html", "structswig__cast__info" ],
    [ "swig_module_info", "structswig__module__info.html", "structswig__module__info" ],
    [ "PyHeapTypeObject", "structPyHeapTypeObject.html", "structPyHeapTypeObject" ],
    [ "swig_const_info", "structswig__const__info.html", "structswig__const__info" ],
    [ "SwigPyClientData", "structSwigPyClientData.html", "structSwigPyClientData" ],
    [ "SwigPyObject", "structSwigPyObject.html", "structSwigPyObject" ],
    [ "SwigPyPacked", "structSwigPyPacked.html", "structSwigPyPacked" ],
    [ "swig_globalvar", "structswig__globalvar.html", "structswig__globalvar" ],
    [ "swig_varlinkobject", "structswig__varlinkobject.html", "structswig__varlinkobject" ],
    [ "MY_BLOCK_THREADS", "plplotcmodulePYTHON__wrap_8c.html#ab07c5ca5d88ddb04e8b89cd613ac4236", null ],
    [ "MY_UNBLOCK_THREADS", "plplotcmodulePYTHON__wrap_8c.html#afe4ad0ef86dccb58441ad5e6fc5e3f90", null ],
    [ "myArray_ContiguousFromObject", "plplotcmodulePYTHON__wrap_8c.html#a282b35fb8bd83f9585f4e46a94487680", null ],
    [ "NPY_NO_DEPRECATED_API", "plplotcmodulePYTHON__wrap_8c.html#ab6e6ee86736f9ebb56e74ae21bf3ff8a", null ],
    [ "NPY_PLFLT", "plplotcmodulePYTHON__wrap_8c.html#a55d2ffc6d9e8ea5e40a3668a8cef5850", null ],
    [ "NPY_PLINT", "plplotcmodulePYTHON__wrap_8c.html#abd82ab7398ed26b6732ef113b6df36b7", null ],
    [ "Py_NotImplemented", "plplotcmodulePYTHON__wrap_8c.html#ae5603e8c5fd8ec50c4936e1012a58cb4", null ],
    [ "PY_SSIZE_T_MAX", "plplotcmodulePYTHON__wrap_8c.html#aa5b5990f814eb53730c24c7f911f9132", null ],
    [ "PY_SSIZE_T_MIN", "plplotcmodulePYTHON__wrap_8c.html#a9fbcf3e88f34de99fb3bd045cffd6ce4", null ],
    [ "Py_TYPE", "plplotcmodulePYTHON__wrap_8c.html#afd489119bf6e3552bdaa6bc365e35e59", null ],
    [ "Py_VISIT", "plplotcmodulePYTHON__wrap_8c.html#a8a5af783da2cdbcfdc7c354f635df8be", null ],
    [ "PyDescr_NAME", "plplotcmodulePYTHON__wrap_8c.html#a7b007021fc924eb74eccb0bb05d99ad1", null ],
    [ "PyDescr_TYPE", "plplotcmodulePYTHON__wrap_8c.html#a0d2bc679367576eb4071b8c3bfe13edc", null ],
    [ "PyExc_StopIteration", "plplotcmodulePYTHON__wrap_8c.html#a0cba46b26eb93c57b8b96696ba92adb4", null ],
    [ "PyInt_FromSize_t", "plplotcmodulePYTHON__wrap_8c.html#a2a72c6061f4d23c35a8340448dd0cd2b", null ],
    [ "PyObject_Del", "plplotcmodulePYTHON__wrap_8c.html#a5777895532ba038acdbde39ef6f78a82", null ],
    [ "PyObject_DEL", "plplotcmodulePYTHON__wrap_8c.html#a3e72f1bb4b2af8f115a750f832d421b4", null ],
    [ "PyObject_GenericGetAttr", "plplotcmodulePYTHON__wrap_8c.html#a2d659e3ecdc8d792ec516753e6fd37a2", null ],
    [ "PyOS_snprintf", "plplotcmodulePYTHON__wrap_8c.html#aaf424b640ab3bb23906652e73030992b", null ],
    [ "PySequence_Fast_GET_ITEM", "plplotcmodulePYTHON__wrap_8c.html#ada824e75a50f73e7439516caeaecb478", null ],
    [ "PySequence_Size", "plplotcmodulePYTHON__wrap_8c.html#ae0178153199e3020e8d586e0e50fc796", null ],
    [ "PySequence_Size", "plplotcmodulePYTHON__wrap_8c.html#ae0178153199e3020e8d586e0e50fc796", null ],
    [ "PyString_AsStringAndSize", "plplotcmodulePYTHON__wrap_8c.html#afdc43df5cb9472c0f13c86d8e01aea31", null ],
    [ "SWIG_AcquirePtr", "plplotcmodulePYTHON__wrap_8c.html#aef3a3f2d1e735f02817fb26d61c8ee3d", null ],
    [ "SWIG_AddCast", "plplotcmodulePYTHON__wrap_8c.html#a4f6f5e0444e44e48aef51f6620438a5f", null ],
    [ "SWIG_AddNewMask", "plplotcmodulePYTHON__wrap_8c.html#af7ac7e424b623712f70e9b6640a54853", null ],
    [ "SWIG_AddTmpMask", "plplotcmodulePYTHON__wrap_8c.html#af8527f0123949ec90e05d0fb156c11e3", null ],
    [ "SWIG_addvarlink", "plplotcmodulePYTHON__wrap_8c.html#a49a542a5f7eb7a97541accc2cde0eed9", null ],
    [ "SWIG_arg_fail", "plplotcmodulePYTHON__wrap_8c.html#a01ff9379ead152cc27db42716b5aed9f", null ],
    [ "SWIG_ArgError", "plplotcmodulePYTHON__wrap_8c.html#a95bab7504841595502bac5ed195becc1", null ],
    [ "SWIG_as_voidptr", "plplotcmodulePYTHON__wrap_8c.html#a6dc8f6b962375bf647fc53ecbeca2d20", null ],
    [ "SWIG_as_voidptrptr", "plplotcmodulePYTHON__wrap_8c.html#a46d91724837c8d2846b0b27f8bf1626c", null ],
    [ "SWIG_AttributeError", "plplotcmodulePYTHON__wrap_8c.html#a5c83bd4d8f39d6eed1df7d3444caa2e1", null ],
    [ "SWIG_BADOBJ", "plplotcmodulePYTHON__wrap_8c.html#a8268a243a8a840396db70f745c23c37c", null ],
    [ "SWIG_BUFFER_SIZE", "plplotcmodulePYTHON__wrap_8c.html#a26324fcd1baceab72680dfec078da440", null ],
    [ "SWIG_BUILTIN_INIT", "plplotcmodulePYTHON__wrap_8c.html#aed1090e31bf3997ef5cdce90e61ada96", null ],
    [ "SWIG_BUILTIN_TP_INIT", "plplotcmodulePYTHON__wrap_8c.html#ac67ecff3f1af17659582b9a4f90cf532", null ],
    [ "SWIG_CAST_NEW_MEMORY", "plplotcmodulePYTHON__wrap_8c.html#ac8216459bfd45cbd2be36175ef6f1ccc", null ],
    [ "SWIG_CASTRANKLIMIT", "plplotcmodulePYTHON__wrap_8c.html#a2f15c36f8b66185937b8232640be62e4", null ],
    [ "SWIG_CheckImplicit", "plplotcmodulePYTHON__wrap_8c.html#acc6f7f7ae2459bfdbe0292aeb22f527e", null ],
    [ "SWIG_CheckState", "plplotcmodulePYTHON__wrap_8c.html#a1faed8ca17e98c961611bc35fde708a9", null ],
    [ "SWIG_contract_assert", "plplotcmodulePYTHON__wrap_8c.html#aca11636b220cff70dac286c268c95ee6", null ],
    [ "SWIG_ConvertFunctionPtr", "plplotcmodulePYTHON__wrap_8c.html#a9a8ddc29a77ad0d18dc7d6ca55dd7f92", null ],
    [ "SWIG_ConvertInstance", "plplotcmodulePYTHON__wrap_8c.html#a55a82f2c2bfcd0c1e514392867a5561c", null ],
    [ "SWIG_ConvertMember", "plplotcmodulePYTHON__wrap_8c.html#abb497a1b462ed19945a37c5cffb64de8", null ],
    [ "SWIG_ConvertPacked", "plplotcmodulePYTHON__wrap_8c.html#a870d0838e4e08ed09cb8a5524e91bd56", null ],
    [ "SWIG_ConvertPtr", "plplotcmodulePYTHON__wrap_8c.html#a72b29226ccbfc8ab46f6247435daed44", null ],
    [ "SWIG_ConvertPtrAndOwn", "plplotcmodulePYTHON__wrap_8c.html#acf0a954d9ffc3d37abfb95ab3a1639be", null ],
    [ "SWIG_DelNewMask", "plplotcmodulePYTHON__wrap_8c.html#ab3ead1d5cb36e1d79daf0bb4732957be", null ],
    [ "SWIG_DelTmpMask", "plplotcmodulePYTHON__wrap_8c.html#ac08b44ea4ae9f73b19d915969f301a5d", null ],
    [ "SWIG_DivisionByZero", "plplotcmodulePYTHON__wrap_8c.html#ae4cc0f5599402526dd5c2fdb80d87517", null ],
    [ "SWIG_ERROR", "plplotcmodulePYTHON__wrap_8c.html#acfa11a770d66f9ca6ba170b173c56c94", null ],
    [ "SWIG_Error", "plplotcmodulePYTHON__wrap_8c.html#a01b485cfacae7d870729eea43fb17cb0", null ],
    [ "SWIG_ErrorType", "plplotcmodulePYTHON__wrap_8c.html#a21d4e75f4bb2519f73467e922c7b51d7", null ],
    [ "SWIG_exception_fail", "plplotcmodulePYTHON__wrap_8c.html#a567b84b185b0f14620c063787f998109", null ],
    [ "SWIG_fail", "plplotcmodulePYTHON__wrap_8c.html#ababf56889b69e7a569556eb38cd4f157", null ],
    [ "SWIG_From_double", "plplotcmodulePYTHON__wrap_8c.html#a920116ba77f1ae02cb8ab8730ad22eb9", null ],
    [ "SWIG_GetModule", "plplotcmodulePYTHON__wrap_8c.html#ab97db3bbfc9e3a73de01e1ee95fa0bb5", null ],
    [ "SWIG_IndexError", "plplotcmodulePYTHON__wrap_8c.html#af1ed73e454bdee28cc19369784f56eed", null ],
    [ "SWIG_init", "plplotcmodulePYTHON__wrap_8c.html#a2d71dac1020240ec6993bfc5048a5988", null ],
    [ "SWIG_InstallConstants", "plplotcmodulePYTHON__wrap_8c.html#a9d393ea973fc8a2e2672e885ec06221b", null ],
    [ "SWIG_InternalNewPointerObj", "plplotcmodulePYTHON__wrap_8c.html#a53f02e00ff4e64a8c3e354a0b6aaf0a8", null ],
    [ "SWIG_IOError", "plplotcmodulePYTHON__wrap_8c.html#a9fcdfcd79ad6f30120990223ea16879a", null ],
    [ "SWIG_IsNewObj", "plplotcmodulePYTHON__wrap_8c.html#a5246ae38052e6fa0e3cca2026cdda153", null ],
    [ "SWIG_IsOK", "plplotcmodulePYTHON__wrap_8c.html#aea8ef410fde907633cb76d9d18131fa1", null ],
    [ "SWIG_IsTmpObj", "plplotcmodulePYTHON__wrap_8c.html#aa8f2563a536468b40dc33843d4bb7efe", null ],
    [ "SWIG_MangledTypeQuery", "plplotcmodulePYTHON__wrap_8c.html#a0ca9dc37d343186a34e966b5a8649ac0", null ],
    [ "SWIG_MemoryError", "plplotcmodulePYTHON__wrap_8c.html#ae1cd9de0a75c6d814815a9de66a4a46d", null ],
    [ "SWIG_MustGetPtr", "plplotcmodulePYTHON__wrap_8c.html#a3b25c4552307e2b3cd5d322ff6b0c294", null ],
    [ "SWIG_name", "plplotcmodulePYTHON__wrap_8c.html#acff905e8f0880e6e5bba1495c416a6af", null ],
    [ "SWIG_NewClientData", "plplotcmodulePYTHON__wrap_8c.html#a3b999f80821e34ecc8bded97723003fd", null ],
    [ "SWIG_NewFunctionPtrObj", "plplotcmodulePYTHON__wrap_8c.html#aab2f1993f97bd27040adf9836dafff18", null ],
    [ "SWIG_NewInstanceObj", "plplotcmodulePYTHON__wrap_8c.html#a27e06002d6d8728005edd12c144444c3", null ],
    [ "SWIG_NewMemberObj", "plplotcmodulePYTHON__wrap_8c.html#a4b628289fae4cd1c4ee9be55e1927f65", null ],
    [ "SWIG_NEWOBJ", "plplotcmodulePYTHON__wrap_8c.html#ab00ef4fde02a6d8d9653ea9edb28d3c9", null ],
    [ "SWIG_NEWOBJMASK", "plplotcmodulePYTHON__wrap_8c.html#a0021b435c31c3ab285b5a6f4547719e3", null ],
    [ "SWIG_NewPackedObj", "plplotcmodulePYTHON__wrap_8c.html#ab6d4285e098e13c5797188b2cf77592e", null ],
    [ "SWIG_NewPointerObj", "plplotcmodulePYTHON__wrap_8c.html#a978ff8eb5e32b08b8a1b8399c1994f23", null ],
    [ "SWIG_newvarlink", "plplotcmodulePYTHON__wrap_8c.html#a840e0b11d64ac8d72e9f72d518cc67be", null ],
    [ "SWIG_NullReferenceError", "plplotcmodulePYTHON__wrap_8c.html#aa11fe417abd4c5a02d31cc1a51dee007", null ],
    [ "SWIG_OK", "plplotcmodulePYTHON__wrap_8c.html#af9ecbac56d4c5cd6104ae8f6bb82e9f7", null ],
    [ "SWIG_OLDOBJ", "plplotcmodulePYTHON__wrap_8c.html#a4afcf490ff5b4abbca27ca23d9af288e", null ],
    [ "SWIG_OverflowError", "plplotcmodulePYTHON__wrap_8c.html#ae9c11d011d8390489595f718d7565a8a", null ],
    [ "swig_owntype", "plplotcmodulePYTHON__wrap_8c.html#ae8afee2b61d8b25aa291dc9574882369", null ],
    [ "SWIG_POINTER_DISOWN", "plplotcmodulePYTHON__wrap_8c.html#aa56139a289829795ed651d533826b65e", null ],
    [ "SWIG_POINTER_EXCEPTION", "plplotcmodulePYTHON__wrap_8c.html#a1ad28578247a49297256a8d36c015f3f", null ],
    [ "SWIG_POINTER_IMPLICIT_CONV", "plplotcmodulePYTHON__wrap_8c.html#a28a70d0513a11dd60735baa8e09c9e44", null ],
    [ "SWIG_POINTER_NEW", "plplotcmodulePYTHON__wrap_8c.html#a1d7a891b8fceac04d0954a0e7aaf7d1c", null ],
    [ "SWIG_POINTER_NOSHADOW", "plplotcmodulePYTHON__wrap_8c.html#a4a923a6f2e1436eab52ac29421cb2831", null ],
    [ "SWIG_POINTER_OWN", "plplotcmodulePYTHON__wrap_8c.html#a1a125b0e9c551bb9cdeb21b8e5be5b57", null ],
    [ "SWIG_PY_BINARY", "plplotcmodulePYTHON__wrap_8c.html#a45cd68c9cc0396e2f8c16cc1b50f8c6f", null ],
    [ "SWIG_PY_POINTER", "plplotcmodulePYTHON__wrap_8c.html#a2c3773038cfb197d2d3bf29b9efa4073", null ],
    [ "SWIG_PYBUFFER_SIZE", "plplotcmodulePYTHON__wrap_8c.html#ad604946e2c4cd420d591cd0d4ab95a59", null ],
    [ "SWIG_Python_CallFunctor", "plplotcmodulePYTHON__wrap_8c.html#a709f9240049521dd53af4010e5775ecd", null ],
    [ "SWIG_Python_ConvertPtr", "plplotcmodulePYTHON__wrap_8c.html#a317c93ceaadae6337607e6d58da351f6", null ],
    [ "SWIG_PYTHON_DIRECTOR_NO_VTABLE", "plplotcmodulePYTHON__wrap_8c.html#ac0f9be2b78eb4770640a820a365e968e", null ],
    [ "SWIG_PYTHON_INITIALIZE_THREADS", "plplotcmodulePYTHON__wrap_8c.html#af5f88d8a220c62e7ee2604ebaf37b920", null ],
    [ "SWIG_Python_Raise", "plplotcmodulePYTHON__wrap_8c.html#ab44c6be9067567689102ab757dad6ea0", null ],
    [ "SWIG_Python_str_DelForPy3", "plplotcmodulePYTHON__wrap_8c.html#a866b998f49f1870f2a0af8e30c738d15", null ],
    [ "SWIG_Python_str_FromFormat", "plplotcmodulePYTHON__wrap_8c.html#a9b793ab094535913288a25a20906bc8e", null ],
    [ "SWIG_PYTHON_THREAD_BEGIN_ALLOW", "plplotcmodulePYTHON__wrap_8c.html#afcf771f05d7d2e2508d33c729ed06df9", null ],
    [ "SWIG_PYTHON_THREAD_BEGIN_BLOCK", "plplotcmodulePYTHON__wrap_8c.html#afc4dd083ffcb3bc22ea34b1f3c4afd7c", null ],
    [ "SWIG_PYTHON_THREAD_END_ALLOW", "plplotcmodulePYTHON__wrap_8c.html#acbaf738de1eb9d87f30c14046482544f", null ],
    [ "SWIG_PYTHON_THREAD_END_BLOCK", "plplotcmodulePYTHON__wrap_8c.html#a320aff2875f19ba4cfb71eefd84fd618", null ],
    [ "SWIG_RUNTIME_VERSION", "plplotcmodulePYTHON__wrap_8c.html#a4895907de5539551925ab5c03ea05d28", null ],
    [ "SWIG_RuntimeError", "plplotcmodulePYTHON__wrap_8c.html#a34d3d1c1310427d00140bf1cc8de3ef6", null ],
    [ "SWIG_SetErrorMsg", "plplotcmodulePYTHON__wrap_8c.html#a47f0648c02682836188562820e28e9c5", null ],
    [ "SWIG_SetErrorObj", "plplotcmodulePYTHON__wrap_8c.html#a874120d0e9be7616d706e1bfe98cfe6f", null ],
    [ "SWIG_SetModule", "plplotcmodulePYTHON__wrap_8c.html#a673a7dcc5c15f5cffa7072785a6c7972", null ],
    [ "SWIG_STATIC_POINTER", "plplotcmodulePYTHON__wrap_8c.html#aa58fdef163810db36a21536e3fef11fc", null ],
    [ "SWIG_SyntaxError", "plplotcmodulePYTHON__wrap_8c.html#a1c4e29c043d3220cedca539360e07148", null ],
    [ "SWIG_SystemError", "plplotcmodulePYTHON__wrap_8c.html#ae4a7b4ce78e031cbf5227bea38d81221", null ],
    [ "SWIG_TMPOBJ", "plplotcmodulePYTHON__wrap_8c.html#ab1fe70ae34b39b709eb4cfb084862236", null ],
    [ "SWIG_TMPOBJMASK", "plplotcmodulePYTHON__wrap_8c.html#a399dafc6302bd9b309041d5570ae94c9", null ],
    [ "SWIG_TYPE_TABLE_NAME", "plplotcmodulePYTHON__wrap_8c.html#ac619a84edecccb5e00c1b4a3180b8c3a", null ],
    [ "SWIG_TypeError", "plplotcmodulePYTHON__wrap_8c.html#a2685345a18f9d5fe8a390ec8500cb916", null ],
    [ "SWIG_TypeQuery", "plplotcmodulePYTHON__wrap_8c.html#a184d005bbcde85bc7d3f652de20d10b3", null ],
    [ "SWIG_UnknownError", "plplotcmodulePYTHON__wrap_8c.html#a45817cd389e6f40d0ffb004ff0678031", null ],
    [ "SWIG_ValueError", "plplotcmodulePYTHON__wrap_8c.html#a4c1b15a2401d60351d98df9327886280", null ],
    [ "SWIG_VERSION", "plplotcmodulePYTHON__wrap_8c.html#a8180a5d9a951bc3a9c5852fce5fde4e8", null ],
    [ "SWIGEXPORT", "plplotcmodulePYTHON__wrap_8c.html#aea3c8b056dcc8c1ab93f6b825cd1371b", null ],
    [ "SWIGINLINE", "plplotcmodulePYTHON__wrap_8c.html#a6d0a7c65b3712775e92c8bdb7acdd0ee", null ],
    [ "SWIGINTERN", "plplotcmodulePYTHON__wrap_8c.html#a8f2319f775e5b9d5906c9ef25d9b819a", null ],
    [ "SWIGINTERNINLINE", "plplotcmodulePYTHON__wrap_8c.html#afc5b08bb3c3cd2e3fb2e34b775346153", null ],
    [ "SWIGPYTHON", "plplotcmodulePYTHON__wrap_8c.html#a8db301777472eabaccb1d609dcedb54e", null ],
    [ "SWIGRUNTIME", "plplotcmodulePYTHON__wrap_8c.html#a42cd9c1d67d803040a3e78515945afcb", null ],
    [ "SWIGRUNTIMEINLINE", "plplotcmodulePYTHON__wrap_8c.html#affa7aa2bcce5bea24a20e5b184ae0533", null ],
    [ "SWIGSTDCALL", "plplotcmodulePYTHON__wrap_8c.html#adcd6410456ea7a76147d3ad95b9bcb36", null ],
    [ "SWIGTEMPLATEDISAMBIGUATOR", "plplotcmodulePYTHON__wrap_8c.html#a7e84031693895e512662f5b390c6d0e4", null ],
    [ "SWIGTYPE_p_char", "plplotcmodulePYTHON__wrap_8c.html#a4fea528f7738d5fc0e2f14911d2b9d38", null ],
    [ "SWIGTYPE_p_double", "plplotcmodulePYTHON__wrap_8c.html#ae614b9773454184a45966a0750727b9d", null ],
    [ "SWIGTYPE_p_f_double_double__int", "plplotcmodulePYTHON__wrap_8c.html#af0600c84bffb86e3577df30fe36d3425", null ],
    [ "SWIGTYPE_p_f_double_double_p_double_p_double_p_void__void", "plplotcmodulePYTHON__wrap_8c.html#a48b31267a66347025b9c355ccfbd54a9", null ],
    [ "SWIGTYPE_p_f_int_double_p_char_int_p_void__void", "plplotcmodulePYTHON__wrap_8c.html#ad7e79c86e7c871c2e72af2844fbf46d9", null ],
    [ "SWIGTYPE_p_f_int_p_double_p_double__void", "plplotcmodulePYTHON__wrap_8c.html#ae94c3b6e426b2f10008f5a3c2f56af92", null ],
    [ "SWIGTYPE_p_f_int_p_q_const__double_p_q_const__double__void", "plplotcmodulePYTHON__wrap_8c.html#a5f4f8d97e6e3d08d8690b7f64d05e93e", null ],
    [ "SWIGTYPE_p_int", "plplotcmodulePYTHON__wrap_8c.html#a73413c3e668627181e90558738caccd5", null ],
    [ "SWIGTYPE_p_p_char", "plplotcmodulePYTHON__wrap_8c.html#ae62a09763b43a6f895de430344a26b80", null ],
    [ "SWIGTYPE_p_p_double", "plplotcmodulePYTHON__wrap_8c.html#a9ca4064d87fbf44deefc2a6a15e6ab2f", null ],
    [ "SWIGTYPE_p_PLcGrid", "plplotcmodulePYTHON__wrap_8c.html#a31eb04c55a134e38b43ab1cf19521d5f", null ],
    [ "SWIGTYPE_p_PLcGrid2", "plplotcmodulePYTHON__wrap_8c.html#aff212a71284c2334decc63896e7e8cb5", null ],
    [ "SWIGTYPE_p_PLGraphicsIn", "plplotcmodulePYTHON__wrap_8c.html#a2a00b161b1ee44d933693f234ca003e5", null ],
    [ "SWIGTYPE_p_unsigned_int", "plplotcmodulePYTHON__wrap_8c.html#ac97b19aa5dc7dde3dfd22b663edbca22", null ],
    [ "SWIGUNUSED", "plplotcmodulePYTHON__wrap_8c.html#a6ee41cd160d397aa76668bf4db65e2d1", null ],
    [ "SWIGUNUSEDPARM", "plplotcmodulePYTHON__wrap_8c.html#a6a54164d0685c632e7540c5ad32a453a", null ],
    [ "SWIGVERSION", "plplotcmodulePYTHON__wrap_8c.html#a82758940324a80fe482f130cc097c36e", null ],
    [ "t_output_helper", "plplotcmodulePYTHON__wrap_8c.html#a4e28792dd57ec3bf53c959afeb54bc99", null ],
    [ "charbufferproc", "plplotcmodulePYTHON__wrap_8c.html#a250efddeec782b8e392f0bbd1e3616ce", null ],
    [ "ct_func", "plplotcmodulePYTHON__wrap_8c.html#a595f4b3960322d1991cb097ff49edb3f", null ],
    [ "defined_func", "plplotcmodulePYTHON__wrap_8c.html#aead6f867c497426f7186863e3851644f", null ],
    [ "f2eval_func", "plplotcmodulePYTHON__wrap_8c.html#a5fe6f22b8e29a47aa53b073eadc90065", null ],
    [ "fill_func", "plplotcmodulePYTHON__wrap_8c.html#a18b05e8276c2f5a41addeea4dd595184", null ],
    [ "freefunc", "plplotcmodulePYTHON__wrap_8c.html#aaa452a52dbfb432ac57356bef6a98869", null ],
    [ "label_func", "plplotcmodulePYTHON__wrap_8c.html#a24e6529701ca8aa4bf683b08b8f8ca3c", null ],
    [ "lenfunc", "plplotcmodulePYTHON__wrap_8c.html#ab788af0e61fbcb9e956ffab774effdd8", null ],
    [ "mapform_func", "plplotcmodulePYTHON__wrap_8c.html#aa6d42edeb63fc7047fe2a4b75171afaa", null ],
    [ "pltr_func", "plplotcmodulePYTHON__wrap_8c.html#a3c135a6feccda3fdd1146327cab6c7a9", null ],
    [ "Py_ssize_t", "plplotcmodulePYTHON__wrap_8c.html#a47424a8953c340f500027db7e6c00173", null ],
    [ "readbufferproc", "plplotcmodulePYTHON__wrap_8c.html#a4fb5dde22554b2e8cbf604eaf6b8fc53", null ],
    [ "segcountproc", "plplotcmodulePYTHON__wrap_8c.html#a3acdde82ecb98e156c428ab351bb400f", null ],
    [ "ssizeargfunc", "plplotcmodulePYTHON__wrap_8c.html#a877107c05c5a27060991092fa4a49c09", null ],
    [ "ssizeobjargproc", "plplotcmodulePYTHON__wrap_8c.html#abec895f1f50377688fdefbfc88ebfbc0", null ],
    [ "ssizessizeargfunc", "plplotcmodulePYTHON__wrap_8c.html#adebcc81bd8317e05dd4dc1a4f5f09b55", null ],
    [ "ssizessizeobjargproc", "plplotcmodulePYTHON__wrap_8c.html#ac9aa1a93b62dd2053cd6b141c877099a", null ],
    [ "swig_cast_info", "plplotcmodulePYTHON__wrap_8c.html#a9a04e6e78de723759e5450cd29429d1f", null ],
    [ "swig_const_info", "plplotcmodulePYTHON__wrap_8c.html#a2faf08f62de0382e80ea7cb79ff39520", null ],
    [ "swig_converter_func", "plplotcmodulePYTHON__wrap_8c.html#a2c314f22b391bfcaff5a11f4b76f66ec", null ],
    [ "swig_dycast_func", "plplotcmodulePYTHON__wrap_8c.html#ad9f16e529633c78df7a780b9749395ce", null ],
    [ "swig_globalvar", "plplotcmodulePYTHON__wrap_8c.html#a99e25fd506c4724a7c2f0432599aca62", null ],
    [ "swig_module_info", "plplotcmodulePYTHON__wrap_8c.html#acf7d83901372902dd5cf59a611dfb320", null ],
    [ "swig_type_info", "plplotcmodulePYTHON__wrap_8c.html#a838fee418372997705a565cd6ecd3b22", null ],
    [ "swig_varlinkobject", "plplotcmodulePYTHON__wrap_8c.html#ae2c8796e1052cedfc9117bd7cc81e7c1", null ],
    [ "writebufferproc", "plplotcmodulePYTHON__wrap_8c.html#a73671bbcb7aaa4b6221c5df016c52d7f", null ],
    [ "callback_type", "plplotcmodulePYTHON__wrap_8c.html#a13a8d6af967152eab3b76a550c8d9836", [
      [ "CB_0", "plplotcmodulePYTHON__wrap_8c.html#a13a8d6af967152eab3b76a550c8d9836ad1818bfe0cdf3890bbd72889e6d1a3ef", null ],
      [ "CB_1", "plplotcmodulePYTHON__wrap_8c.html#a13a8d6af967152eab3b76a550c8d9836aa374b0fc98c195ab8a48f9316540a1a5", null ],
      [ "CB_2", "plplotcmodulePYTHON__wrap_8c.html#a13a8d6af967152eab3b76a550c8d9836ac8f39bb05080b79a2a3c5e9335c15bc1", null ],
      [ "CB_Python", "plplotcmodulePYTHON__wrap_8c.html#a13a8d6af967152eab3b76a550c8d9836ad2b3bc083d087517cb0a4ba68577ee01", null ]
    ] ],
    [ "_SWIG_This", "plplotcmodulePYTHON__wrap_8c.html#ab6b9406572a75bad483f518bcfcdfd9a", null ],
    [ "_wrap_delete_PLGraphicsIn", "plplotcmodulePYTHON__wrap_8c.html#a886576b14ea272828ea20c4ce2a74c1e", null ],
    [ "_wrap_new_PLGraphicsIn", "plplotcmodulePYTHON__wrap_8c.html#aca3bfc8e4feaf984c9f8ad6ddedd7e5b", null ],
    [ "_wrap_pl_setcontlabelformat", "plplotcmodulePYTHON__wrap_8c.html#ad26b9962843eebbeb5c02dbdc1c4c489", null ],
    [ "_wrap_pl_setcontlabelparam", "plplotcmodulePYTHON__wrap_8c.html#aa7fee74a2fc606a911f5e139fce26b83", null ],
    [ "_wrap_pladv", "plplotcmodulePYTHON__wrap_8c.html#a905fb9992c4ce0e1258c95cff9246883", null ],
    [ "_wrap_plarc", "plplotcmodulePYTHON__wrap_8c.html#a88b122cb7ca4c03b89362ef8aab29be4", null ],
    [ "_wrap_plaxes", "plplotcmodulePYTHON__wrap_8c.html#a75c5c46b7e5bb6e7e4f3de46b7abfc50", null ],
    [ "_wrap_plbin", "plplotcmodulePYTHON__wrap_8c.html#a9984f44cdd91846b161700f07afc3211", null ],
    [ "_wrap_plbop", "plplotcmodulePYTHON__wrap_8c.html#aa584c07fae29e35461e2b6a63741137f", null ],
    [ "_wrap_plbox", "plplotcmodulePYTHON__wrap_8c.html#ae9bc0290d2b3dba1e7993a557f22ec29", null ],
    [ "_wrap_plbox3", "plplotcmodulePYTHON__wrap_8c.html#a035fe8189afe879b5954fb172f86f1c4", null ],
    [ "_wrap_plbtime", "plplotcmodulePYTHON__wrap_8c.html#a8be33d1872c82ab12b6346415c2f3277", null ],
    [ "_wrap_plcalc_world", "plplotcmodulePYTHON__wrap_8c.html#ae67b73e2b7edc1dcde4ebcae91f4d7a4", null ],
    [ "_wrap_plclear", "plplotcmodulePYTHON__wrap_8c.html#a0b340750cff575d0c8f08f765e2b257b", null ],
    [ "_wrap_plClearOpts", "plplotcmodulePYTHON__wrap_8c.html#af60f5ab2176d94fdd675f314a1198338", null ],
    [ "_wrap_plcol0", "plplotcmodulePYTHON__wrap_8c.html#acec64c2ea36f075667d47518055a92c2", null ],
    [ "_wrap_plcol1", "plplotcmodulePYTHON__wrap_8c.html#a8bcd941da44b6a3841035aec6e916047", null ],
    [ "_wrap_plcolorbar", "plplotcmodulePYTHON__wrap_8c.html#aa3178c94b74d50ba3d2cee9ba814e6bf", null ],
    [ "_wrap_plconfigtime", "plplotcmodulePYTHON__wrap_8c.html#a9f8a201a030c64a61db78f5005a15e00", null ],
    [ "_wrap_plcont", "plplotcmodulePYTHON__wrap_8c.html#a382149020683277f3683b77539d478e6", null ],
    [ "_wrap_plcpstrm", "plplotcmodulePYTHON__wrap_8c.html#a40f2a5099d630e37f442b41934095986", null ],
    [ "_wrap_plctime", "plplotcmodulePYTHON__wrap_8c.html#abc6e69ea47b0b7d7160e092a865e761f", null ],
    [ "_wrap_plend", "plplotcmodulePYTHON__wrap_8c.html#ad11109e50b023f2f1e26d33b79af0145", null ],
    [ "_wrap_plend1", "plplotcmodulePYTHON__wrap_8c.html#a5d900a47d32209a8ad49eb639c0217a4", null ],
    [ "_wrap_plenv", "plplotcmodulePYTHON__wrap_8c.html#a69a550cfcf9d26091b974cdcf06bad31", null ],
    [ "_wrap_plenv0", "plplotcmodulePYTHON__wrap_8c.html#a19e940786e67169cd18ee3f1d854b0a8", null ],
    [ "_wrap_pleop", "plplotcmodulePYTHON__wrap_8c.html#a6ec9a9b28b68fbecedb4dec35c6ba0e6", null ],
    [ "_wrap_plerrx", "plplotcmodulePYTHON__wrap_8c.html#a39ebb1b2aa72f14c1f262bb7df69489c", null ],
    [ "_wrap_plerry", "plplotcmodulePYTHON__wrap_8c.html#ae957aa94dae82c7b8b922b4c628658ee", null ],
    [ "_wrap_plfamadv", "plplotcmodulePYTHON__wrap_8c.html#ab00d41ce2f1cc48821bedeaa523bb76d", null ],
    [ "_wrap_plfill", "plplotcmodulePYTHON__wrap_8c.html#a160d26a86f72cb22227596e000d8df48", null ],
    [ "_wrap_plfill3", "plplotcmodulePYTHON__wrap_8c.html#a6e029883fe9771eefa7ce40893d06ce2", null ],
    [ "_wrap_plflush", "plplotcmodulePYTHON__wrap_8c.html#add17c0f18d67743bf3f674fba2e637e1", null ],
    [ "_wrap_plfont", "plplotcmodulePYTHON__wrap_8c.html#a66b1dee79cb30529f156f6b7fc86e89f", null ],
    [ "_wrap_plfontld", "plplotcmodulePYTHON__wrap_8c.html#a64b43b90b84cae7cd8e44474e11abb1c", null ],
    [ "_wrap_plgchr", "plplotcmodulePYTHON__wrap_8c.html#a4d65d972590b1e3c0aaa9a61308ee8af", null ],
    [ "_wrap_plgcmap1_range", "plplotcmodulePYTHON__wrap_8c.html#a84fc0b6d5cd253d8f03fbd398541ed5d", null ],
    [ "_wrap_plgcol0", "plplotcmodulePYTHON__wrap_8c.html#a34eace3bf9d5b65cee712ee7eeca92f4", null ],
    [ "_wrap_plgcol0a", "plplotcmodulePYTHON__wrap_8c.html#a3fc255f8c3a8efae57289420993f1bac", null ],
    [ "_wrap_plgcolbg", "plplotcmodulePYTHON__wrap_8c.html#ad223969212af6537ca99419b455e214d", null ],
    [ "_wrap_plgcolbga", "plplotcmodulePYTHON__wrap_8c.html#a74e7ee57028bda44ab55d01c42a390b7", null ],
    [ "_wrap_plgcompression", "plplotcmodulePYTHON__wrap_8c.html#a5ed07de67971d6a511530e90e68159e0", null ],
    [ "_wrap_plgdev", "plplotcmodulePYTHON__wrap_8c.html#a08dcfc463899ffa1d1b8c76f8820fbda", null ],
    [ "_wrap_plgdidev", "plplotcmodulePYTHON__wrap_8c.html#a463d9b43837e97510696215b2b0f89b5", null ],
    [ "_wrap_plgdiori", "plplotcmodulePYTHON__wrap_8c.html#ac38d06cee9f5df24c426c5c68ffe8541", null ],
    [ "_wrap_plgdiplt", "plplotcmodulePYTHON__wrap_8c.html#a5da6be57ce8f5e9a1c570faf0b4feb17", null ],
    [ "_wrap_plGetCursor", "plplotcmodulePYTHON__wrap_8c.html#a73be2ed50a3507e51d9ae4dc98e64342", null ],
    [ "_wrap_plgfam", "plplotcmodulePYTHON__wrap_8c.html#a1282d79b6dd92af539d089bf7de43e74", null ],
    [ "_wrap_plgfci", "plplotcmodulePYTHON__wrap_8c.html#aa9984f416a894856349bc677aec3e1c3", null ],
    [ "_wrap_plgfnam", "plplotcmodulePYTHON__wrap_8c.html#a381268b47ad1a46c5600962a38fb8126", null ],
    [ "_wrap_plgfont", "plplotcmodulePYTHON__wrap_8c.html#af99b4f11faae0961451e1556fe8b61f8", null ],
    [ "_wrap_plglevel", "plplotcmodulePYTHON__wrap_8c.html#a49c2e0b9441b05c39531a81b499c2bc5", null ],
    [ "_wrap_plgpage", "plplotcmodulePYTHON__wrap_8c.html#a370d09048fe3589754ca32fbc61b08e8", null ],
    [ "_wrap_plgra", "plplotcmodulePYTHON__wrap_8c.html#a768ae2cfb5907111abf54cf3110594df", null ],
    [ "_wrap_plgradient", "plplotcmodulePYTHON__wrap_8c.html#adb15cc73fb19b5442ca2f36148b10f68", null ],
    [ "_wrap_PLGraphicsIn_button_get", "plplotcmodulePYTHON__wrap_8c.html#a488985aa6a030f732c7634a77024fa91", null ],
    [ "_wrap_PLGraphicsIn_button_set", "plplotcmodulePYTHON__wrap_8c.html#a16e45f11fc7d35cafccb91db23c20f3d", null ],
    [ "_wrap_PLGraphicsIn_dX_get", "plplotcmodulePYTHON__wrap_8c.html#aab1e7800d265f784da8a870270ff8d55", null ],
    [ "_wrap_PLGraphicsIn_dX_set", "plplotcmodulePYTHON__wrap_8c.html#aa8359bdfe390954dcb2d6f9504366d65", null ],
    [ "_wrap_PLGraphicsIn_dY_get", "plplotcmodulePYTHON__wrap_8c.html#a0527a8d1f182f20b212bfae51a40e812", null ],
    [ "_wrap_PLGraphicsIn_dY_set", "plplotcmodulePYTHON__wrap_8c.html#a02a0d646b3eb8c7dd6d4ce41718ce04a", null ],
    [ "_wrap_PLGraphicsIn_keysym_get", "plplotcmodulePYTHON__wrap_8c.html#a822b058bac375b158292b060407b2cd1", null ],
    [ "_wrap_PLGraphicsIn_keysym_set", "plplotcmodulePYTHON__wrap_8c.html#a81fb53088587ba4d06db992d9746f2df", null ],
    [ "_wrap_PLGraphicsIn_pX_get", "plplotcmodulePYTHON__wrap_8c.html#a7804f62d876e31be2456332bf7506ba1", null ],
    [ "_wrap_PLGraphicsIn_pX_set", "plplotcmodulePYTHON__wrap_8c.html#a85c9951423fba748383f7f008014770c", null ],
    [ "_wrap_PLGraphicsIn_pY_get", "plplotcmodulePYTHON__wrap_8c.html#aee82caa0e40d4b2437b2ba0b8cc3e8cf", null ],
    [ "_wrap_PLGraphicsIn_pY_set", "plplotcmodulePYTHON__wrap_8c.html#a0fa358a63d09a9afa09e989b8bfa8ad6", null ],
    [ "_wrap_PLGraphicsIn_state_get", "plplotcmodulePYTHON__wrap_8c.html#a8e7bf7bf62952346b44d65f454414557", null ],
    [ "_wrap_PLGraphicsIn_state_set", "plplotcmodulePYTHON__wrap_8c.html#ad6db9d6cdeb6ce93d05ec8960e667418", null ],
    [ "_wrap_PLGraphicsIn_string_get", "plplotcmodulePYTHON__wrap_8c.html#a05b404bc7fdec8cd8fd0e899a7f6cc71", null ],
    [ "_wrap_PLGraphicsIn_string_set", "plplotcmodulePYTHON__wrap_8c.html#abdc803c1740ad5df84da16bd48433e66", null ],
    [ "_wrap_PLGraphicsIn_subwindow_get", "plplotcmodulePYTHON__wrap_8c.html#ab8001b13a01a632f84611c82ce79b5ed", null ],
    [ "_wrap_PLGraphicsIn_subwindow_set", "plplotcmodulePYTHON__wrap_8c.html#ad960fbdff0c638a2135ce212cb1c578d", null ],
    [ "_wrap_PLGraphicsIn_type_get", "plplotcmodulePYTHON__wrap_8c.html#a90efaa693bb185230d771ba1911566d4", null ],
    [ "_wrap_PLGraphicsIn_type_set", "plplotcmodulePYTHON__wrap_8c.html#aa8621d09923375dd8008393056fd5391", null ],
    [ "_wrap_PLGraphicsIn_wX_get", "plplotcmodulePYTHON__wrap_8c.html#a2d3179354f819933471f366ab530de5c", null ],
    [ "_wrap_PLGraphicsIn_wX_set", "plplotcmodulePYTHON__wrap_8c.html#aeecebacf17f73c78364f72d12c755a2c", null ],
    [ "_wrap_PLGraphicsIn_wY_get", "plplotcmodulePYTHON__wrap_8c.html#a80a429dd67de6b0650c84379cc40365a", null ],
    [ "_wrap_PLGraphicsIn_wY_set", "plplotcmodulePYTHON__wrap_8c.html#ae9c65c14c09d24660dd30e4762ed4304", null ],
    [ "_wrap_plgriddata", "plplotcmodulePYTHON__wrap_8c.html#a0f350e1c0f23a8ab793ce52dd611062b", null ],
    [ "_wrap_plgspa", "plplotcmodulePYTHON__wrap_8c.html#a19968b4591a872c3f8dd1e67b04915bc", null ],
    [ "_wrap_plgstrm", "plplotcmodulePYTHON__wrap_8c.html#a807e31d433ac4aace09866103caef325", null ],
    [ "_wrap_plgver", "plplotcmodulePYTHON__wrap_8c.html#abc8e70cd93bb29e60e4ce7c41fb6f785", null ],
    [ "_wrap_plgvpd", "plplotcmodulePYTHON__wrap_8c.html#a1b96cf3f11d49ea67282961eb89dcd14", null ],
    [ "_wrap_plgvpw", "plplotcmodulePYTHON__wrap_8c.html#a110a3032c027cb0d9cdeb52b50208ff5", null ],
    [ "_wrap_plgxax", "plplotcmodulePYTHON__wrap_8c.html#a5b0fc69c91620f8ddde3bc94c55cd79e", null ],
    [ "_wrap_plgyax", "plplotcmodulePYTHON__wrap_8c.html#a4f8d6b2356323d4e34796f500f177d2d", null ],
    [ "_wrap_plgzax", "plplotcmodulePYTHON__wrap_8c.html#ad87f2e1ea70ffc6ac5230827c122fcb9", null ],
    [ "_wrap_plhist", "plplotcmodulePYTHON__wrap_8c.html#ac98533aa258b13cec5884be2769b92d1", null ],
    [ "_wrap_plhlsrgb", "plplotcmodulePYTHON__wrap_8c.html#af3032d65196c5f4c5de401b547a8d14d", null ],
    [ "_wrap_plimage", "plplotcmodulePYTHON__wrap_8c.html#ae8eb3cd33b1f6ad322ce911bb1ec950c", null ],
    [ "_wrap_plimagefr", "plplotcmodulePYTHON__wrap_8c.html#a35ae58d4253c1405fe5879a1fb9155ed", null ],
    [ "_wrap_plinit", "plplotcmodulePYTHON__wrap_8c.html#ad033d9ebe797ad3c18f6e7718cc342e7", null ],
    [ "_wrap_pljoin", "plplotcmodulePYTHON__wrap_8c.html#aaace0a684efb751b2ea18bf0831650e5", null ],
    [ "_wrap_pllab", "plplotcmodulePYTHON__wrap_8c.html#aa9e63eee6125e836489f6e396eaf81ba", null ],
    [ "_wrap_pllegend", "plplotcmodulePYTHON__wrap_8c.html#a335472bcc8240c89b99b678ff762871c", null ],
    [ "_wrap_pllightsource", "plplotcmodulePYTHON__wrap_8c.html#ab3c4e9314773bcf5e774046c39e1bd3b", null ],
    [ "_wrap_plline", "plplotcmodulePYTHON__wrap_8c.html#a896fc13c7e0cd54435a358aad2b9a413", null ],
    [ "_wrap_plline3", "plplotcmodulePYTHON__wrap_8c.html#a89a070c6b6b522c95d8fa9006e920bf1", null ],
    [ "_wrap_pllsty", "plplotcmodulePYTHON__wrap_8c.html#aba9d692f444c206c4cdae297147c55a6", null ],
    [ "_wrap_plmap", "plplotcmodulePYTHON__wrap_8c.html#a5f10b5e080208c3718a9ec1a601d34fb", null ],
    [ "_wrap_plmapfill", "plplotcmodulePYTHON__wrap_8c.html#a5871478c3ebcde368937901ce0daa2b2", null ],
    [ "_wrap_plmapline", "plplotcmodulePYTHON__wrap_8c.html#ab88b604b872bf011a07222477c61962d", null ],
    [ "_wrap_plmapstring", "plplotcmodulePYTHON__wrap_8c.html#aeda987ea974a9d8089e8a67fa8531ca6", null ],
    [ "_wrap_plmaptex", "plplotcmodulePYTHON__wrap_8c.html#a608ce2a34b4ef08a694df51d00375f7d", null ],
    [ "_wrap_plmeridians", "plplotcmodulePYTHON__wrap_8c.html#abb6c8d5f3dc9ef39f5fef8a137df399a", null ],
    [ "_wrap_plmesh", "plplotcmodulePYTHON__wrap_8c.html#a8a9003ba25ee12ff8d44f7bbdb56bf24", null ],
    [ "_wrap_plmeshc", "plplotcmodulePYTHON__wrap_8c.html#a48f5c55480808a873284ec90b3f7887b", null ],
    [ "_wrap_plMinMax2dGrid", "plplotcmodulePYTHON__wrap_8c.html#afa8c2333be06b0775a32610268158daf", null ],
    [ "_wrap_plmkstrm", "plplotcmodulePYTHON__wrap_8c.html#a870c8704036e8b6e71005f2521af9724", null ],
    [ "_wrap_plmtex", "plplotcmodulePYTHON__wrap_8c.html#a17c179437f80c7c88fe9060bf87dbd3d", null ],
    [ "_wrap_plmtex3", "plplotcmodulePYTHON__wrap_8c.html#a55bb15f973c03da0381c789c0b0b8d26", null ],
    [ "_wrap_plOptUsage", "plplotcmodulePYTHON__wrap_8c.html#a823ad427e4cea5726110bdff2edc53c7", null ],
    [ "_wrap_plot3d", "plplotcmodulePYTHON__wrap_8c.html#aa8cfa16f09eb68169622be9ca973e99f", null ],
    [ "_wrap_plot3dc", "plplotcmodulePYTHON__wrap_8c.html#aa684d9bfd6d2477aac399aca64d922f4", null ],
    [ "_wrap_plot3dcl", "plplotcmodulePYTHON__wrap_8c.html#a27a360be92110a7cdb4653513b066168", null ],
    [ "_wrap_plparseopts", "plplotcmodulePYTHON__wrap_8c.html#af522c80723107be5ea9784bd8f2b8ac2", null ],
    [ "_wrap_plpat", "plplotcmodulePYTHON__wrap_8c.html#a48771fa5e34c6c5e11f90b22715fdf97", null ],
    [ "_wrap_plpath", "plplotcmodulePYTHON__wrap_8c.html#a04346a912e109a81b6a1a184e988937f", null ],
    [ "_wrap_plpoin", "plplotcmodulePYTHON__wrap_8c.html#a9678304a4b846ba5163bd255b4ee9419", null ],
    [ "_wrap_plpoin3", "plplotcmodulePYTHON__wrap_8c.html#a33434a23d59ae890e1f42e42ed7b160f", null ],
    [ "_wrap_plpoly3", "plplotcmodulePYTHON__wrap_8c.html#aa184b9428ee98a2e17a100682e27aa60", null ],
    [ "_wrap_plprec", "plplotcmodulePYTHON__wrap_8c.html#aaf4101c92af6e9ae149770e2b6443f00", null ],
    [ "_wrap_plpsty", "plplotcmodulePYTHON__wrap_8c.html#a5b469bec5809e1f9a2a1b620323be565", null ],
    [ "_wrap_plptex", "plplotcmodulePYTHON__wrap_8c.html#af253f571d670bb7d28d021f1b04e9c79", null ],
    [ "_wrap_plptex3", "plplotcmodulePYTHON__wrap_8c.html#aea24f7e7cd486a3bef285bf2b492cf64", null ],
    [ "_wrap_plrandd", "plplotcmodulePYTHON__wrap_8c.html#ab5255649a7f92dccfe95a73c0622bebf", null ],
    [ "_wrap_plreplot", "plplotcmodulePYTHON__wrap_8c.html#a3ca663d9ae91285900945ba8784dda5f", null ],
    [ "_wrap_plResetOpts", "plplotcmodulePYTHON__wrap_8c.html#a96be1702f7b2152df1b81ebd5094a0e5", null ],
    [ "_wrap_plrgbhls", "plplotcmodulePYTHON__wrap_8c.html#a23876a9a492631a8b87b3a2ea30c94fa", null ],
    [ "_wrap_plschr", "plplotcmodulePYTHON__wrap_8c.html#a9393bd5ac04f9f1b417a648dca36779a", null ],
    [ "_wrap_plscmap0", "plplotcmodulePYTHON__wrap_8c.html#ab71d2a6006009fddd5f09e819b519010", null ],
    [ "_wrap_plscmap0a", "plplotcmodulePYTHON__wrap_8c.html#a857c1335cc428cacd8afa777af6043ee", null ],
    [ "_wrap_plscmap0n", "plplotcmodulePYTHON__wrap_8c.html#a11ce3caa6f9e87985cd24517c33f3192", null ],
    [ "_wrap_plscmap1", "plplotcmodulePYTHON__wrap_8c.html#a54296ae8e6952e07c2d0d0f56d22ab38", null ],
    [ "_wrap_plscmap1_range", "plplotcmodulePYTHON__wrap_8c.html#a59e7645bafbb9abe0ccfa2531567f65d", null ],
    [ "_wrap_plscmap1a", "plplotcmodulePYTHON__wrap_8c.html#add35c523f1e2b5203d976f3e5512f929", null ],
    [ "_wrap_plscmap1l", "plplotcmodulePYTHON__wrap_8c.html#a263560123e8e1e1bbd4abb72eb7281cb", null ],
    [ "_wrap_plscmap1la", "plplotcmodulePYTHON__wrap_8c.html#a61226f7830c8efbe7229032b03625c03", null ],
    [ "_wrap_plscmap1n", "plplotcmodulePYTHON__wrap_8c.html#ab3d72ffc47c4a24a8948921b5f5e8003", null ],
    [ "_wrap_plscol0", "plplotcmodulePYTHON__wrap_8c.html#a52dfdb2ed0492b1400cdd504c9478f3d", null ],
    [ "_wrap_plscol0a", "plplotcmodulePYTHON__wrap_8c.html#aac6af1b348d5bbd45520ea5617b651b0", null ],
    [ "_wrap_plscolbg", "plplotcmodulePYTHON__wrap_8c.html#a9d1becca05a92aa6c24e9d8699b4bca0", null ],
    [ "_wrap_plscolbga", "plplotcmodulePYTHON__wrap_8c.html#ac9de990634802ebee337c9b1b5a127b1", null ],
    [ "_wrap_plscolor", "plplotcmodulePYTHON__wrap_8c.html#ab24c82679b9c6b1916fc1da021848f81", null ],
    [ "_wrap_plscompression", "plplotcmodulePYTHON__wrap_8c.html#ad0d3e5a7bf036bf1c183399883ac1744", null ],
    [ "_wrap_plsdev", "plplotcmodulePYTHON__wrap_8c.html#a6bee7f84c3982c3c47f1deb993086781", null ],
    [ "_wrap_plsdidev", "plplotcmodulePYTHON__wrap_8c.html#a00275cc63b33b60eaa342cf144dc6215", null ],
    [ "_wrap_plsdimap", "plplotcmodulePYTHON__wrap_8c.html#a3b852e1ce95ee9adce6c90d842ec640d", null ],
    [ "_wrap_plsdiori", "plplotcmodulePYTHON__wrap_8c.html#a857f56b9c6690cb42bc1ee706ace16e6", null ],
    [ "_wrap_plsdiplt", "plplotcmodulePYTHON__wrap_8c.html#a8bcb03f2494c9840375f1a3977690eb3", null ],
    [ "_wrap_plsdiplz", "plplotcmodulePYTHON__wrap_8c.html#a75f3cdb017ee70daa4eb4bc856ae1bb4", null ],
    [ "_wrap_plseed", "plplotcmodulePYTHON__wrap_8c.html#ae8d96f35eea81674c98ec3346ba4ea33", null ],
    [ "_wrap_plsesc", "plplotcmodulePYTHON__wrap_8c.html#a168550559d6a02b4bc3c967642ec23c9", null ],
    [ "_wrap_plsetopt", "plplotcmodulePYTHON__wrap_8c.html#ab49ca77b25f378db0b1edce3e25f9a6f", null ],
    [ "_wrap_plSetUsage", "plplotcmodulePYTHON__wrap_8c.html#a4e90a3409228ed0c33ad1e59eaaae5e9", null ],
    [ "_wrap_plsfam", "plplotcmodulePYTHON__wrap_8c.html#a581e54c7561f85f195d1f491597b00bc", null ],
    [ "_wrap_plsfci", "plplotcmodulePYTHON__wrap_8c.html#af618ba3718e409ba5bbee8012eaa798b", null ],
    [ "_wrap_plsfnam", "plplotcmodulePYTHON__wrap_8c.html#a2d9946d320e5c1192bb606ec54cd06fe", null ],
    [ "_wrap_plsfont", "plplotcmodulePYTHON__wrap_8c.html#a5217e57dafb9e8775a10ced4d262a54d", null ],
    [ "_wrap_plshade", "plplotcmodulePYTHON__wrap_8c.html#a872cd140bb841c5d0f0174334bd1b227", null ],
    [ "_wrap_plshades", "plplotcmodulePYTHON__wrap_8c.html#a191ada24e363f71ae08d103c6ead35c4", null ],
    [ "_wrap_plslabelfunc", "plplotcmodulePYTHON__wrap_8c.html#a2fd3d58c53ead38b2fcde4493c9c806b", null ],
    [ "_wrap_plsmaj", "plplotcmodulePYTHON__wrap_8c.html#a958b5cd1651275134e8b2ac43e7e34a1", null ],
    [ "_wrap_plsmem", "plplotcmodulePYTHON__wrap_8c.html#a9667faea93cdc3aaf8e1662de1e88c04", null ],
    [ "_wrap_plsmema", "plplotcmodulePYTHON__wrap_8c.html#a53fabdd9c7f3cd04605f944e39639df5", null ],
    [ "_wrap_plsmin", "plplotcmodulePYTHON__wrap_8c.html#a51af3c117fad425def3a0954e0c9d3ab", null ],
    [ "_wrap_plsori", "plplotcmodulePYTHON__wrap_8c.html#a397c0ea6e68df33c951d86d0e000fae8", null ],
    [ "_wrap_plspage", "plplotcmodulePYTHON__wrap_8c.html#a6c00ef00dfd0a2a34d557a77f449f54e", null ],
    [ "_wrap_plspal0", "plplotcmodulePYTHON__wrap_8c.html#a84845ff21eb80a5d9d449190fb34ae0c", null ],
    [ "_wrap_plspal1", "plplotcmodulePYTHON__wrap_8c.html#a836023470f6bc117d1d1c081791feae5", null ],
    [ "_wrap_plspause", "plplotcmodulePYTHON__wrap_8c.html#a820689e2b02829a63577a2eff26ad34c", null ],
    [ "_wrap_plsstrm", "plplotcmodulePYTHON__wrap_8c.html#a39463c69ff9e9cb46df1dbe5d5768a3e", null ],
    [ "_wrap_plssub", "plplotcmodulePYTHON__wrap_8c.html#a2a45469fbff114158c6eed89f11cab70", null ],
    [ "_wrap_plssym", "plplotcmodulePYTHON__wrap_8c.html#a25b9a4e41b53db50649d4cf07f317cca", null ],
    [ "_wrap_plstar", "plplotcmodulePYTHON__wrap_8c.html#a5a63bff01240f6d70b5cc54c6b582739", null ],
    [ "_wrap_plstart", "plplotcmodulePYTHON__wrap_8c.html#a8ecb4509d3c08510175a51186a145389", null ],
    [ "_wrap_plstransform", "plplotcmodulePYTHON__wrap_8c.html#a8a2fc0cf2a1999d6a9152c9be61d2669", null ],
    [ "_wrap_plstring", "plplotcmodulePYTHON__wrap_8c.html#ae2d88769a63aed121a046c28dccfe970", null ],
    [ "_wrap_plstring3", "plplotcmodulePYTHON__wrap_8c.html#a463e42782dba27cd2912a18ca38848ea", null ],
    [ "_wrap_plstripa", "plplotcmodulePYTHON__wrap_8c.html#a5fac31d066c9a1784372d4c48a86b365", null ],
    [ "_wrap_plstripc", "plplotcmodulePYTHON__wrap_8c.html#a4b73899e8c40adaaafeb7c84baea333b", null ],
    [ "_wrap_plstripd", "plplotcmodulePYTHON__wrap_8c.html#a7a20b0d5ba8bd554b3ece9c9eb5c48ec", null ],
    [ "_wrap_plstyl", "plplotcmodulePYTHON__wrap_8c.html#a93bf3f644ea61973686418511bb4b448", null ],
    [ "_wrap_plsurf3d", "plplotcmodulePYTHON__wrap_8c.html#a378404077b4dafa259bd80fbcdff03ed", null ],
    [ "_wrap_plsurf3dl", "plplotcmodulePYTHON__wrap_8c.html#a79901491e60ff5099be44d6fbed2570f", null ],
    [ "_wrap_plsvect", "plplotcmodulePYTHON__wrap_8c.html#a727eb104e49fa97ed1f193341009bc41", null ],
    [ "_wrap_plsvpa", "plplotcmodulePYTHON__wrap_8c.html#a0521a528b9a320ebc6e09b5e7039c333", null ],
    [ "_wrap_plsxax", "plplotcmodulePYTHON__wrap_8c.html#a08ec8b26bbe1ddd08da972f4f20c4255", null ],
    [ "_wrap_plsxwin", "plplotcmodulePYTHON__wrap_8c.html#a0c286ba9ae67c39b27ecd1bcf340c095", null ],
    [ "_wrap_plsyax", "plplotcmodulePYTHON__wrap_8c.html#ab0036fa9690cbfb601901bd46d016b17", null ],
    [ "_wrap_plsym", "plplotcmodulePYTHON__wrap_8c.html#a3ddc1b94e6b18169256202e6ce35a465", null ],
    [ "_wrap_plszax", "plplotcmodulePYTHON__wrap_8c.html#a2fb1353651e36f74d08899f1a3601cd4", null ],
    [ "_wrap_pltext", "plplotcmodulePYTHON__wrap_8c.html#a35fe2df4ad5da61d43e4eeffbc55f191", null ],
    [ "_wrap_pltimefmt", "plplotcmodulePYTHON__wrap_8c.html#a6ea2b7ea7707e7b2d3e31a8c0343a24b", null ],
    [ "_wrap_pltr0", "plplotcmodulePYTHON__wrap_8c.html#a86987f5d1210972607dca81ac2dcc844", null ],
    [ "_wrap_pltr1", "plplotcmodulePYTHON__wrap_8c.html#a4f2de5ddc758c8041e1bd7407464f0e5", null ],
    [ "_wrap_pltr2", "plplotcmodulePYTHON__wrap_8c.html#a58a04b485e9d6a163756d3fb1d1144cd", null ],
    [ "_wrap_plvasp", "plplotcmodulePYTHON__wrap_8c.html#a7ec04678a1798a9122b278f9def563da", null ],
    [ "_wrap_plvect", "plplotcmodulePYTHON__wrap_8c.html#ae550d3fb38b73f6250030c6e6256152f", null ],
    [ "_wrap_plvpas", "plplotcmodulePYTHON__wrap_8c.html#af4bf462ceceed157bda2035c2c5afba7", null ],
    [ "_wrap_plvpor", "plplotcmodulePYTHON__wrap_8c.html#ac5339f444cb613bcbe524bd67721aa7d", null ],
    [ "_wrap_plvsta", "plplotcmodulePYTHON__wrap_8c.html#a490136b8a92dd80951ee546ab8ec3460", null ],
    [ "_wrap_plw3d", "plplotcmodulePYTHON__wrap_8c.html#a4deddce35f9cca2cc0d8053e2e589ad0", null ],
    [ "_wrap_plwidth", "plplotcmodulePYTHON__wrap_8c.html#a54775f62e62831bdbeeff8c89ec1e93c", null ],
    [ "_wrap_plwind", "plplotcmodulePYTHON__wrap_8c.html#ada73daa3da1888f01f7a424cfd8e40d5", null ],
    [ "_wrap_plxormod", "plplotcmodulePYTHON__wrap_8c.html#a23c17567b79a52a1df2c652a30e12bc1", null ],
    [ "cleanup_ct", "plplotcmodulePYTHON__wrap_8c.html#a567b8a6e77233b620e6e356ce926b0c5", null ],
    [ "cleanup_mapform", "plplotcmodulePYTHON__wrap_8c.html#a20a1f2c307cb467884edd487c715010f", null ],
    [ "cleanup_PLcGrid1", "plplotcmodulePYTHON__wrap_8c.html#a50b51d3c720a3d5516de3052c316fd5b", null ],
    [ "cleanup_PLcGrid2", "plplotcmodulePYTHON__wrap_8c.html#a8e2cf3c60970cb7e7fc7e991a30dff14", null ],
    [ "cleanup_PLPointer", "plplotcmodulePYTHON__wrap_8c.html#a210e38636bba3af6c5db9c8db451475f", null ],
    [ "cleanup_pltr", "plplotcmodulePYTHON__wrap_8c.html#a8d677910d74d3609111bb05a59ee49ec", null ],
    [ "do_ct_callback", "plplotcmodulePYTHON__wrap_8c.html#aa55de72b3611b0c8da14b06623b31d00", null ],
    [ "do_f2eval_callback", "plplotcmodulePYTHON__wrap_8c.html#a186e3ee0d5d1fd3e9dcc77c8946d9607", null ],
    [ "do_label_callback", "plplotcmodulePYTHON__wrap_8c.html#a5b0321ad235146d11e01257ddf5783e2", null ],
    [ "do_mapform_callback", "plplotcmodulePYTHON__wrap_8c.html#a2ad7669c1293909aafb1a4539ae41f4e", null ],
    [ "do_pltr_callback", "plplotcmodulePYTHON__wrap_8c.html#ad26774534ac3b87f0895b44638d77ace", null ],
    [ "marshal_ct", "plplotcmodulePYTHON__wrap_8c.html#a989667f9b811bdb28d8957a36db129b8", null ],
    [ "marshal_mapform", "plplotcmodulePYTHON__wrap_8c.html#a3dcb723ebf6af73d33d811112d204c9f", null ],
    [ "marshal_PLcGrid1", "plplotcmodulePYTHON__wrap_8c.html#ab8d83df7fed27110cb89493f68fc3f70", null ],
    [ "marshal_PLcGrid2", "plplotcmodulePYTHON__wrap_8c.html#ade7fcfd6a60a5170767fb83caa317aa9", null ],
    [ "marshal_PLPointer", "plplotcmodulePYTHON__wrap_8c.html#a6c2db43a5f44e492c76fd5cc731bd4a0", null ],
    [ "marshal_pltr", "plplotcmodulePYTHON__wrap_8c.html#a26e5fa5490e0403caeecbf316f06e374", null ],
    [ "myIntArray_ContiguousFromObject", "plplotcmodulePYTHON__wrap_8c.html#afaf9be66e21f0a9ba0f06e0154abe005", null ],
    [ "myIntArray_ContiguousFromObject", "plplotcmodulePYTHON__wrap_8c.html#a6a9924bbfb276811af503d0b56439f93", null ],
    [ "PLGraphicsIn_swigregister", "plplotcmodulePYTHON__wrap_8c.html#a4fbd4cbc85b45330b2d4330a2b0434dd", null ],
    [ "PyBool_FromLong", "plplotcmodulePYTHON__wrap_8c.html#a9e8dba7cf79abba80fcd013e115ff3ce", null ],
    [ "PyModule_AddObject", "plplotcmodulePYTHON__wrap_8c.html#a6a7f8a8dbdf7d7609e23b646bb88c64f", null ],
    [ "PyNumber_AsSsize_t", "plplotcmodulePYTHON__wrap_8c.html#af4996a75e1273fbeb7105c31fa1b14ea", null ],
    [ "PyString_FromFormat", "plplotcmodulePYTHON__wrap_8c.html#a544a84d4178631debdffb22dde886b8b", null ],
    [ "SWIG_AsCharArray", "plplotcmodulePYTHON__wrap_8c.html#aca4108ad0ef99668ccece28805f35467", null ],
    [ "SWIG_AsCharPtrAndSize", "plplotcmodulePYTHON__wrap_8c.html#aeb4ebd3d270c7d0a5303f10393485505", null ],
    [ "SWIG_AsVal_char", "plplotcmodulePYTHON__wrap_8c.html#a9305ecbf3be42460931d54d97c54a87f", null ],
    [ "SWIG_AsVal_double", "plplotcmodulePYTHON__wrap_8c.html#a14604bc0932d6a4a99475970ac783697", null ],
    [ "SWIG_AsVal_int", "plplotcmodulePYTHON__wrap_8c.html#ac5d34218467df201deab1b9f5cad6691", null ],
    [ "SWIG_AsVal_long", "plplotcmodulePYTHON__wrap_8c.html#aca3c78b106b24b292a156d1f2e9d6bf7", null ],
    [ "SWIG_AsVal_unsigned_SS_int", "plplotcmodulePYTHON__wrap_8c.html#a917ff3106efe8a0a541987056a73260c", null ],
    [ "SWIG_AsVal_unsigned_SS_long", "plplotcmodulePYTHON__wrap_8c.html#a41e8e3f07bd0f6952fa4aed604822081", null ],
    [ "SWIG_CanCastAsInteger", "plplotcmodulePYTHON__wrap_8c.html#a4101ce628ad9db6a901cca96a6d36ae6", null ],
    [ "SWIG_From_int", "plplotcmodulePYTHON__wrap_8c.html#a72dbc0b72daa1f0a0d7adc533dd5239b", null ],
    [ "SWIG_From_unsigned_SS_int", "plplotcmodulePYTHON__wrap_8c.html#a084afaf9aaaa39d54153d5ed902688e4", null ],
    [ "SWIG_FromCharPtrAndSize", "plplotcmodulePYTHON__wrap_8c.html#aab193d49d264f79c432d393916bf35bc", null ],
    [ "SWIG_globals", "plplotcmodulePYTHON__wrap_8c.html#ab494e9006843d36bd778308ada0e84b0", null ],
    [ "SWIG_init", "plplotcmodulePYTHON__wrap_8c.html#a2c97d7ac5d594f63f25b263f20acb428", null ],
    [ "SWIG_InitializeModule", "plplotcmodulePYTHON__wrap_8c.html#a7f8da48fe4dbc23aef01a714623b8a6b", null ],
    [ "SWIG_MangledTypeQueryModule", "plplotcmodulePYTHON__wrap_8c.html#ac63ad9b58a96793188f944c92ff40ec6", null ],
    [ "SWIG_PackData", "plplotcmodulePYTHON__wrap_8c.html#a02c2ac3db8ce87dd62813334e66c9a3a", null ],
    [ "SWIG_PackDataName", "plplotcmodulePYTHON__wrap_8c.html#af903e6809a1fb2ba06deff49795c6e65", null ],
    [ "SWIG_PackVoidPtr", "plplotcmodulePYTHON__wrap_8c.html#a10c5572eb6206df7c95c8a2fcde90911", null ],
    [ "SWIG_pchar_descriptor", "plplotcmodulePYTHON__wrap_8c.html#ae71b7c9eeb1f89aa554cb897ecef348f", null ],
    [ "SWIG_PropagateClientData", "plplotcmodulePYTHON__wrap_8c.html#abc08944d526c952dc121d3d1b84f0d16", null ],
    [ "SWIG_Py_Void", "plplotcmodulePYTHON__wrap_8c.html#a695030dbc62bde212c7b7a9169c6eee9", null ],
    [ "SWIG_PyInstanceMethod_New", "plplotcmodulePYTHON__wrap_8c.html#a61fe613c1736ff484fb2f18642544f57", null ],
    [ "SWIG_Python_AcquirePtr", "plplotcmodulePYTHON__wrap_8c.html#afddb1b639fb789e0f8aa35e8e5f2635f", null ],
    [ "SWIG_Python_AddErrMesg", "plplotcmodulePYTHON__wrap_8c.html#a26ba14592b463c53ad77c11ae322e44f", null ],
    [ "SWIG_Python_AddErrorMsg", "plplotcmodulePYTHON__wrap_8c.html#a95cdd9c41903a3fc5911ecc5c617da3f", null ],
    [ "SWIG_Python_addvarlink", "plplotcmodulePYTHON__wrap_8c.html#a3fef5c393b26d8f975b18e1d6785b501", null ],
    [ "SWIG_Python_AppendOutput", "plplotcmodulePYTHON__wrap_8c.html#aff1e04c88e5de68ef034fbea50a52fc6", null ],
    [ "SWIG_Python_ArgFail", "plplotcmodulePYTHON__wrap_8c.html#ab3ea77456a0202171540ab01c6e3e4f7", null ],
    [ "SWIG_Python_CheckImplicit", "plplotcmodulePYTHON__wrap_8c.html#adccbcbf6df87e38c5a227a9b5c7f70e4", null ],
    [ "SWIG_Python_ConvertFunctionPtr", "plplotcmodulePYTHON__wrap_8c.html#aab4c16474d452d70b81f765cd430f661", null ],
    [ "SWIG_Python_ConvertPacked", "plplotcmodulePYTHON__wrap_8c.html#a03b3793a4bd02ab2e9dda57331f4b5f3", null ],
    [ "SWIG_Python_ConvertPtrAndOwn", "plplotcmodulePYTHON__wrap_8c.html#ab5bec3f786db25fd4085c1534d785a0d", null ],
    [ "SWIG_Python_DestroyModule", "plplotcmodulePYTHON__wrap_8c.html#a7d3ea178e7face372657bf426fa15410", null ],
    [ "SWIG_Python_ErrorType", "plplotcmodulePYTHON__wrap_8c.html#a538bcfd0ca57105e5dea178a302b7f89", null ],
    [ "SWIG_Python_ExceptionType", "plplotcmodulePYTHON__wrap_8c.html#a153f638306c56e8204656c79dce8cf2e", null ],
    [ "SWIG_Python_FixMethods", "plplotcmodulePYTHON__wrap_8c.html#addfee1cf672308dcdd030d489f804b5f", null ],
    [ "SWIG_Python_GetModule", "plplotcmodulePYTHON__wrap_8c.html#ac85fea1d3188d4ee0517aa685d7bcde3", null ],
    [ "SWIG_Python_GetSwigThis", "plplotcmodulePYTHON__wrap_8c.html#a9160b127bcb2cef38bc6432c28b533c2", null ],
    [ "SWIG_Python_InitShadowInstance", "plplotcmodulePYTHON__wrap_8c.html#a77d3a8e01e24edf05e663b16f914e947", null ],
    [ "SWIG_Python_InstallConstants", "plplotcmodulePYTHON__wrap_8c.html#a26d87efa9c8072a9092913538ab5090c", null ],
    [ "SWIG_Python_MustGetPtr", "plplotcmodulePYTHON__wrap_8c.html#aa8fb00ee4c6f504b3bd4d5710c124c2c", null ],
    [ "SWIG_Python_NewPackedObj", "plplotcmodulePYTHON__wrap_8c.html#a552754ea0a5290f4fa6d3181ff226cc2", null ],
    [ "SWIG_Python_NewPointerObj", "plplotcmodulePYTHON__wrap_8c.html#a6c4b024081777ebd6c3b275d0cb3fddb", null ],
    [ "SWIG_Python_NewShadowInstance", "plplotcmodulePYTHON__wrap_8c.html#a73eb27cce2019a9dda04cb97b417bf1b", null ],
    [ "SWIG_Python_newvarlink", "plplotcmodulePYTHON__wrap_8c.html#a4cfb5662fdbfb858849ded6ebd2e05e8", null ],
    [ "SWIG_Python_SetConstant", "plplotcmodulePYTHON__wrap_8c.html#a995ded01a54051855bda3b831ec86a5c", null ],
    [ "SWIG_Python_SetErrorMsg", "plplotcmodulePYTHON__wrap_8c.html#aab548920dbf42ee6139485ca36c72c1e", null ],
    [ "SWIG_Python_SetErrorObj", "plplotcmodulePYTHON__wrap_8c.html#a92b9f2ba549f0c2e0c5118436f6c786c", null ],
    [ "SWIG_Python_SetModule", "plplotcmodulePYTHON__wrap_8c.html#a97dcf2ac96af7ac919ccb8784322945d", null ],
    [ "SWIG_Python_SetSwigThis", "plplotcmodulePYTHON__wrap_8c.html#a7510f33190dba6f3a77bd18d891e6c38", null ],
    [ "SWIG_Python_str_AsChar", "plplotcmodulePYTHON__wrap_8c.html#a933a38459f11308f715f19c1c0269682", null ],
    [ "SWIG_Python_str_FromChar", "plplotcmodulePYTHON__wrap_8c.html#a0ba3b72d0eb29ff47379e6e77b21d78a", null ],
    [ "SWIG_Python_TypeCache", "plplotcmodulePYTHON__wrap_8c.html#af654af2b686a4768f226970719c13bf2", null ],
    [ "SWIG_Python_TypeError", "plplotcmodulePYTHON__wrap_8c.html#ac487bf25fd5238c01ad35edf4dde586f", null ],
    [ "SWIG_Python_TypeQuery", "plplotcmodulePYTHON__wrap_8c.html#a00a2aa9762204b8a6a82fb5b1e0ef24c", null ],
    [ "SWIG_Python_UnpackTuple", "plplotcmodulePYTHON__wrap_8c.html#a4b77323d83b752aadf1134d7ff0194b2", null ],
    [ "SWIG_This", "plplotcmodulePYTHON__wrap_8c.html#a6af4e531324a053514434bbdeb0c3b8b", null ],
    [ "SWIG_TypeCast", "plplotcmodulePYTHON__wrap_8c.html#a334486cb1e8f569c949a0384cbdb2a16", null ],
    [ "SWIG_TypeCheck", "plplotcmodulePYTHON__wrap_8c.html#abd0cb78a9663e41312c8f14ab6715f04", null ],
    [ "SWIG_TypeCheckStruct", "plplotcmodulePYTHON__wrap_8c.html#a898a1dfcdf96d53a2c7fd90e8500b36e", null ],
    [ "SWIG_TypeClientData", "plplotcmodulePYTHON__wrap_8c.html#a4b0a40223812f7d43bc2f0c2342fe2f7", null ],
    [ "SWIG_TypeCmp", "plplotcmodulePYTHON__wrap_8c.html#a73131c439c907ed987c34da85b95a597", null ],
    [ "SWIG_TypeDynamicCast", "plplotcmodulePYTHON__wrap_8c.html#add8cb1a47628b36915ffa37d61452b1e", null ],
    [ "SWIG_TypeEquiv", "plplotcmodulePYTHON__wrap_8c.html#a23ecf039d651082ffc7582c4f50af780", null ],
    [ "SWIG_TypeName", "plplotcmodulePYTHON__wrap_8c.html#a68560e0bf641c9691704d6d05bac4358", null ],
    [ "SWIG_TypeNameComp", "plplotcmodulePYTHON__wrap_8c.html#a2f69ad4207037cb391a2b2d5915fcba2", null ],
    [ "SWIG_TypeNewClientData", "plplotcmodulePYTHON__wrap_8c.html#a710082a7ea6978d654bad712dbebc0ee", null ],
    [ "SWIG_TypePrettyName", "plplotcmodulePYTHON__wrap_8c.html#a3f38ea686cb3f85bf6a15b08416f2684", null ],
    [ "SWIG_TypeQueryModule", "plplotcmodulePYTHON__wrap_8c.html#a5b6a2719f95288678fa55ade4493b175", null ],
    [ "SWIG_UnpackData", "plplotcmodulePYTHON__wrap_8c.html#a80e9e66f66413297452de92c69cdf9d7", null ],
    [ "SWIG_UnpackDataName", "plplotcmodulePYTHON__wrap_8c.html#a99540d89d9ffca957892cf22af3e49dd", null ],
    [ "SWIG_UnpackVoidPtr", "plplotcmodulePYTHON__wrap_8c.html#ae3e13f3464cb74f7e5d9f7a50a6855c0", null ],
    [ "swig_varlink_dealloc", "plplotcmodulePYTHON__wrap_8c.html#ad2b4927c9caa8562938bb95fa2323d5b", null ],
    [ "swig_varlink_getattr", "plplotcmodulePYTHON__wrap_8c.html#a25b6ac5e60ad191347e0c14deccc64c7", null ],
    [ "swig_varlink_print", "plplotcmodulePYTHON__wrap_8c.html#aab6c4c0c3d6f7cb066d1bf494ee909c1", null ],
    [ "swig_varlink_repr", "plplotcmodulePYTHON__wrap_8c.html#a8f7bb58cf5697eb4ad02dddc21d3484b", null ],
    [ "swig_varlink_setattr", "plplotcmodulePYTHON__wrap_8c.html#a2ec84ff72b3bb939d9930127720a1104", null ],
    [ "swig_varlink_str", "plplotcmodulePYTHON__wrap_8c.html#a1499f2083c0786d2e54042e92ac3ef6a", null ],
    [ "swig_varlink_type", "plplotcmodulePYTHON__wrap_8c.html#a68f13f09a32e1018533406a5f5cb004f", null ],
    [ "SwigPyClientData_Del", "plplotcmodulePYTHON__wrap_8c.html#acfc84d6965502d26fff3ac72e1bf5702", null ],
    [ "SwigPyClientData_New", "plplotcmodulePYTHON__wrap_8c.html#a919f062d24409c7a7b727a8acea354a8", null ],
    [ "SwigPyObject_acquire", "plplotcmodulePYTHON__wrap_8c.html#a668721644f7dbe75a1fbf943cf95970b", null ],
    [ "SwigPyObject_append", "plplotcmodulePYTHON__wrap_8c.html#ad0d9e76a55857f9bbdc7fcdcfb67d85d", null ],
    [ "SwigPyObject_Check", "plplotcmodulePYTHON__wrap_8c.html#a918ad69f91e617193f190aed101c3cc4", null ],
    [ "SwigPyObject_compare", "plplotcmodulePYTHON__wrap_8c.html#a72434475ffb4b712774fb65344cf0292", null ],
    [ "SwigPyObject_dealloc", "plplotcmodulePYTHON__wrap_8c.html#a31a09386e839d2080e2f56602c011263", null ],
    [ "SwigPyObject_disown", "plplotcmodulePYTHON__wrap_8c.html#a43969c210565e7f0816802cd8e23f1e3", null ],
    [ "SwigPyObject_format", "plplotcmodulePYTHON__wrap_8c.html#a6d2977b4ede610f6c7ef7fcad053237b", null ],
    [ "SwigPyObject_getattr", "plplotcmodulePYTHON__wrap_8c.html#a68eddc0684157ef121380451acbbfa1f", null ],
    [ "SwigPyObject_GetDesc", "plplotcmodulePYTHON__wrap_8c.html#a5cf26bf08c897ac8dbe4cd7ca37ba518", null ],
    [ "SwigPyObject_hex", "plplotcmodulePYTHON__wrap_8c.html#a655c2dc99f0ce059357b97600a9d274a", null ],
    [ "SwigPyObject_long", "plplotcmodulePYTHON__wrap_8c.html#abc24d5684dfe838e99fc155a38160d84", null ],
    [ "SwigPyObject_New", "plplotcmodulePYTHON__wrap_8c.html#adaf049b6445afcfd0890cabe0d5539d4", null ],
    [ "SwigPyObject_next", "plplotcmodulePYTHON__wrap_8c.html#a598fccf9f94eedbb7de3432be6f21bbe", null ],
    [ "SwigPyObject_oct", "plplotcmodulePYTHON__wrap_8c.html#ac19d035c2f2617b773fb7b3bea5a26b3", null ],
    [ "SwigPyObject_own", "plplotcmodulePYTHON__wrap_8c.html#a4a9e73ab689dd1de8182907b582194aa", null ],
    [ "SwigPyObject_repr", "plplotcmodulePYTHON__wrap_8c.html#a72e362e1099bd1b9a1d124c11a101a81", null ],
    [ "SwigPyObject_richcompare", "plplotcmodulePYTHON__wrap_8c.html#ae977913145e8a243228c8e90fbe5f2ca", null ],
    [ "SwigPyObject_type", "plplotcmodulePYTHON__wrap_8c.html#a70268be3151a2c800628b561be2b3d6d", null ],
    [ "SwigPyObject_TypeOnce", "plplotcmodulePYTHON__wrap_8c.html#aea7d4126c1b77d06d8fcdf22619e9d77", null ],
    [ "SwigPyPacked_Check", "plplotcmodulePYTHON__wrap_8c.html#a6fea38d61cc362fd7b67a9fa56b33307", null ],
    [ "SwigPyPacked_compare", "plplotcmodulePYTHON__wrap_8c.html#a144e704aba25130c8e02b60d8c738fa2", null ],
    [ "SwigPyPacked_dealloc", "plplotcmodulePYTHON__wrap_8c.html#ad8ae205f122aca20da861fa915a332b0", null ],
    [ "SwigPyPacked_New", "plplotcmodulePYTHON__wrap_8c.html#a52562b3b604cdf2e9aca9f051bbdd471", null ],
    [ "SwigPyPacked_print", "plplotcmodulePYTHON__wrap_8c.html#a474b4790df1707c1c1165c167c10e256", null ],
    [ "SwigPyPacked_repr", "plplotcmodulePYTHON__wrap_8c.html#a7035b519064392d397664bd5a3f4f42b", null ],
    [ "SwigPyPacked_str", "plplotcmodulePYTHON__wrap_8c.html#a7b50e11124d8cb98a44bef2cb264fab9", null ],
    [ "SwigPyPacked_type", "plplotcmodulePYTHON__wrap_8c.html#ac30ddd16af5a205cdd11d72da2d771e7", null ],
    [ "SwigPyPacked_TypeOnce", "plplotcmodulePYTHON__wrap_8c.html#a31a57967e5b47748769603196022a988", null ],
    [ "SwigPyPacked_UnpackData", "plplotcmodulePYTHON__wrap_8c.html#ad74e19c2bcb96391fc1ec3cd3e8396a5", null ],
    [ "_swigc__p_char", "plplotcmodulePYTHON__wrap_8c.html#a8848127146fe0444e2fe3183a15b67f5", null ],
    [ "_swigc__p_double", "plplotcmodulePYTHON__wrap_8c.html#a28b7f0e03111f37524cf093e3a8a2304", null ],
    [ "_swigc__p_f_double_double__int", "plplotcmodulePYTHON__wrap_8c.html#a207f66749bdba90b94fc94339a002520", null ],
    [ "_swigc__p_f_double_double_p_double_p_double_p_void__void", "plplotcmodulePYTHON__wrap_8c.html#a3f4c37068cdd295d0dafa913f043216e", null ],
    [ "_swigc__p_f_int_double_p_char_int_p_void__void", "plplotcmodulePYTHON__wrap_8c.html#abd7eee4930f48e2326a9df35e20f0bba", null ],
    [ "_swigc__p_f_int_p_double_p_double__void", "plplotcmodulePYTHON__wrap_8c.html#a5c2379fb009e6c97a5de4731c20e4283", null ],
    [ "_swigc__p_f_int_p_q_const__double_p_q_const__double__void", "plplotcmodulePYTHON__wrap_8c.html#af6625b2b7918b35eddbed9053fad7905", null ],
    [ "_swigc__p_int", "plplotcmodulePYTHON__wrap_8c.html#a216d8b24b856092e2e65830ef290159b", null ],
    [ "_swigc__p_p_char", "plplotcmodulePYTHON__wrap_8c.html#adf82b09513b48dd2275acc2fa74711b7", null ],
    [ "_swigc__p_p_double", "plplotcmodulePYTHON__wrap_8c.html#a8ef572e7214cb0eedcc6419377664472", null ],
    [ "_swigc__p_PLcGrid", "plplotcmodulePYTHON__wrap_8c.html#ab71600ff158f81ba0f2ad17add084b68", null ],
    [ "_swigc__p_PLcGrid2", "plplotcmodulePYTHON__wrap_8c.html#a15ad6cd2c38c0be50be771105a0e60a6", null ],
    [ "_swigc__p_PLGraphicsIn", "plplotcmodulePYTHON__wrap_8c.html#adbc9470f42e7e3c0a2adab2df09b950d", null ],
    [ "_swigc__p_unsigned_int", "plplotcmodulePYTHON__wrap_8c.html#aba9e61dc970ecfa60bf8a90276b1daa9", null ],
    [ "_swigt__p_char", "plplotcmodulePYTHON__wrap_8c.html#ae66f44191f70db7b9634a8321766c840", null ],
    [ "_swigt__p_double", "plplotcmodulePYTHON__wrap_8c.html#a650096f8d16b87549437da125768b407", null ],
    [ "_swigt__p_f_double_double__int", "plplotcmodulePYTHON__wrap_8c.html#aa99dba7c5dc196a6edb638363e104be7", null ],
    [ "_swigt__p_f_double_double_p_double_p_double_p_void__void", "plplotcmodulePYTHON__wrap_8c.html#a169d330528354eea0e80046288f7a240", null ],
    [ "_swigt__p_f_int_double_p_char_int_p_void__void", "plplotcmodulePYTHON__wrap_8c.html#ad192a829bb4110f62a13c396ab965321", null ],
    [ "_swigt__p_f_int_p_double_p_double__void", "plplotcmodulePYTHON__wrap_8c.html#ac93b2bfcffa54c72401ce0fe924336ef", null ],
    [ "_swigt__p_f_int_p_q_const__double_p_q_const__double__void", "plplotcmodulePYTHON__wrap_8c.html#a8a3b05af198a366e7d91148da9aa0695", null ],
    [ "_swigt__p_int", "plplotcmodulePYTHON__wrap_8c.html#abb18e7711ddb7deeaf40f89dd6643b2c", null ],
    [ "_swigt__p_p_char", "plplotcmodulePYTHON__wrap_8c.html#a701773c68706ee07319dc186a10ec151", null ],
    [ "_swigt__p_p_double", "plplotcmodulePYTHON__wrap_8c.html#a7142a8246b533266bb0a1ec0e07d0516", null ],
    [ "_swigt__p_PLcGrid", "plplotcmodulePYTHON__wrap_8c.html#ac62d4edffb73674c8eb44ee0965094fc", null ],
    [ "_swigt__p_PLcGrid2", "plplotcmodulePYTHON__wrap_8c.html#aefc05597d3afa2cf5e60f169e7326c10", null ],
    [ "_swigt__p_PLGraphicsIn", "plplotcmodulePYTHON__wrap_8c.html#aa7423ef65fc1e3d9cc8e9acb90b31531", null ],
    [ "_swigt__p_unsigned_int", "plplotcmodulePYTHON__wrap_8c.html#ac758895aa5c2bb2a384d76af7fc77b2c", null ],
    [ "Alen", "plplotcmodulePYTHON__wrap_8c.html#a27d25ac7e864031d461a8a5460144223", null ],
    [ "pltr_type", "plplotcmodulePYTHON__wrap_8c.html#ac1ba1957081dd47cfc51c81b349fb65a", null ],
    [ "pltr_xg", "plplotcmodulePYTHON__wrap_8c.html#abc329ab5d5455e741b49a7cfca82b74c", null ],
    [ "pltr_yg", "plplotcmodulePYTHON__wrap_8c.html#acab766c33a03fec035a91e4d28e150a2", null ],
    [ "python_ct", "plplotcmodulePYTHON__wrap_8c.html#accd45e261658e868dbba9789704cb8d5", null ],
    [ "python_f2eval", "plplotcmodulePYTHON__wrap_8c.html#a487895e00ae9be090c71512415fc35d6", null ],
    [ "python_label", "plplotcmodulePYTHON__wrap_8c.html#a728cbc7612574a50db094ae556e4b368", null ],
    [ "python_mapform", "plplotcmodulePYTHON__wrap_8c.html#aa64bb28869b331ad013625fbad5cdf57", null ],
    [ "python_pltr", "plplotcmodulePYTHON__wrap_8c.html#a9606f0b730c8f4c62e20c00e2dfde1c6", null ],
    [ "swig_cast_initial", "plplotcmodulePYTHON__wrap_8c.html#a0666e347f7d486a3bc82b78efd732333", null ],
    [ "swig_const_table", "plplotcmodulePYTHON__wrap_8c.html#a6e606ed3240900e595e177ed9012d009", null ],
    [ "swig_module", "plplotcmodulePYTHON__wrap_8c.html#a5f41f6e106d3195e660a39e5292f50fd", null ],
    [ "swig_this", "plplotcmodulePYTHON__wrap_8c.html#aa46bee1d6fc5b229095ab118d8925636", null ],
    [ "swig_type_initial", "plplotcmodulePYTHON__wrap_8c.html#ad621c8a05a43cf3a48467c791142bb44", null ],
    [ "swig_types", "plplotcmodulePYTHON__wrap_8c.html#af4809c9a7db4f3441c30d3f462a52de0", null ],
    [ "SwigMethods", "plplotcmodulePYTHON__wrap_8c.html#aa03a15903621be80f4e3b2017e74d115", null ],
    [ "swigobject_methods", "plplotcmodulePYTHON__wrap_8c.html#a4e964af1d130dbfe312a46f36c39e2b8", null ],
    [ "tmpGrid1", "plplotcmodulePYTHON__wrap_8c.html#a10288494689ad1ff78bd513bc5fdff03", null ],
    [ "tmpGrid2", "plplotcmodulePYTHON__wrap_8c.html#a0954ceefa7066553c144e782a2da9228", null ],
    [ "Xlen", "plplotcmodulePYTHON__wrap_8c.html#ac91c25f032882cfbd3e877adb9dd788d", null ],
    [ "Ylen", "plplotcmodulePYTHON__wrap_8c.html#a63da9b8b39f2bb3fdf520fdc1dd0870a", null ]
];